﻿--[[ $Id: PlayerMenu.lua 70828 2008-04-22 03:41:29Z hshh $ ]]--
PlayerMenu = LibStub("AceAddon-3.0"):NewAddon("PlayerMenu", "AceConsole-3.0", "AceEvent-3.0", "AceHook-3.0", "AceTimer-3.0")
local L = LibStub("AceLocale-3.0"):GetLocale("PlayerMenu")

--save blizzard origin variables
local menus = {"FRIEND", "PLAYER", "PARTY", "RAID_PLAYER"}
local menus_new_items = {"GUILD_INVITE", "ADD_FRIEND", "GET_NAME", "WHO"}
local PM_BLZ_ORIGIN = {}
local m,k,v
local _G = getfenv(0)
for _,m in ipairs(menus) do
	PM_BLZ_ORIGIN[m]={}
	for k,v in pairs(_G.UnitPopupMenus[m]) do
		PM_BLZ_ORIGIN[m][k]=v
	end
end

local ExtMaxButton = 20


--db get/set function
local function get(info)
    local k = info[#info]
	return PlayerMenu.db.profile[k]
end
local function set(info,value)
    local k = info[#info]
    PlayerMenu.db.profile[k] = value
end

function PlayerMenu:OnInitialize()
	local defaults = {
		profile = {
			leftButton = false,
		}
	}
	self.db = LibStub("AceDB-3.0"):New("PlayerMenu_Settings", defaults, "Default")

	local options = {
		type = "group",
		get = get,
		set = set,
		args = {
			leftButton = {
				order = 100,
				type = "toggle",
				name = L["Left Button Menu"],
				desc = L["Mouse left click to show menu"],
			},
			resetdb = {
				order = 500,
				type = "execute",
				name = L["Reset"],
				confirm = true,
				confirmText = L["ResetDB_Confirm"],
				func = function()
					self.db:ResetDB()
					self:OnDisable()
					self:OnEnable()
					self:Print(L["All settings are reset to default value."])
				end,
			},
		}
	}
	LibStub("AceConfig-3.0"):RegisterOptionsTable("PlayerMenu", options)
	LibStub("AceConfigDialog-3.0"):AddToBlizOptions("PlayerMenu", "PlayerMenu")
end

function PlayerMenu:OnEnable()
	self:SecureHook("UnitPopup_OnClick")
	self:SecureHook("UnitPopup_HideButtons")
	if (self.db.profile.leftButton) then
		self:SecureHook("SetItemRef")
	end

	local v,vv
	for _,v in ipairs(menus_new_items) do
		UnitPopupButtons[v] = { text = L[v], dist = 0 }
		for _,vv in ipairs(menus) do
			tinsert(UnitPopupMenus[vv], getn(UnitPopupMenus[vv])-1, v)
		end
	end
end

function PlayerMenu:OnDisable()
	local v,vv,kkk,vvv
	for _,v in ipairs(menus_new_items) do
		for _,vv in ipairs(menus) do
			UnitPopupMenus[vv]={}
			for kkk,vvv in pairs(PM_BLZ_ORIGIN[vv]) do
				UnitPopupMenus[vv][kkk]=vvv
			end
		end
		UnitPopupButtons[v] = nil
	end
end

function PlayerMenu:UnitPopup_HideButtons()
	local dropdownMenu = UIDROPDOWNMENU_INIT_MENU
	local diffFactionGroup
	if dropdownMenu.unit and UnitFactionGroup("player") ~= UnitFactionGroup(dropdownMenu.unit) then
		diffFactionGroup = true
	end
	local realm
	if dropdownMenu.unit then
		_,realm = UnitName(dropdownMenu.unit)
	end

	for index, value in ipairs(UnitPopupMenus[dropdownMenu.which]) do
		if value == "GET_NAME" then
			if dropdownMenu.name == UnitName("player") then
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][index] = 0
			else
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][index] = 1
			end
		elseif value == "WHO" or value == "ADD_FRIEND" then
			if dropdownMenu.name == UnitName("player") or (realm and realm ~="") or diffFactionGroup then
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][index] = 0
			else
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][index] = 1
			end
		elseif value == "GUILD_INVITE" then
			if not CanGuildInvite() or dropdownMenu.name == UnitName("player") or (realm and realm ~="") or diffFactionGroup then
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][index] = 0
			else
				UnitPopupShown[UIDROPDOWNMENU_MENU_LEVEL][index] = 1
			end
		end
	end
end

function PlayerMenu:UnitPopup_OnClick()
	local dropdownFrame = UIDROPDOWNMENU_INIT_MENU
	local button = this.value
	local name = dropdownFrame.name

	if (button == "ADD_FRIEND") then
		AddFriend(name)
	elseif (button == "GUILD_INVITE") then
		GuildInvite(name)
	elseif (button == "GET_NAME") then
		ChatFrameEditBox:Show()
		local realm
		if dropdownFrame.unit then
			_,realm = UnitName(dropdownFrame.unit)
		end
		if (realm and realm ~="") then
			ChatFrameEditBox:Insert(name .. " - " .. realm)
		else
			ChatFrameEditBox:Insert(name)
		end
	elseif (button == "WHO") then
		SendWho(name)
	end
	PlaySound("UChatScrollButton")
end

function PlayerMenu:SetItemRef(link, text, button)
	if ( strsub(link, 1, 6) == "player" ) then
		local namelink = strsub(link, 8);
		local name, lineid = strsplit(":", namelink);
		if ( name and (strlen(name) > 0) ) then
			if ( IsModifiedClick("CHATLINK") ) then
				local staticPopup;
				staticPopup = StaticPopup_Visible("ADD_IGNORE");
				if ( staticPopup ) then
					-- If add ignore dialog is up then enter the name into the editbox
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				staticPopup = StaticPopup_Visible("ADD_MUTE");
				if ( staticPopup ) then
					-- If add ignore dialog is up then enter the name into the editbox
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				staticPopup = StaticPopup_Visible("ADD_FRIEND");
				if ( staticPopup ) then
					-- If add ignore dialog is up then enter the name into the editbox
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				staticPopup = StaticPopup_Visible("ADD_GUILDMEMBER");
				if ( staticPopup ) then
					-- If add ignore dialog is up then enter the name into the editbox
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				staticPopup = StaticPopup_Visible("ADD_TEAMMEMBER");
				if ( staticPopup ) then
					-- If add ignore dialog is up then enter the name into the editbox
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				staticPopup = StaticPopup_Visible("ADD_RAIDMEMBER");
				if ( staticPopup ) then
					-- If add ignore dialog is up then enter the name into the editbox
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				staticPopup = StaticPopup_Visible("CHANNEL_INVITE");
				if ( staticPopup ) then
					getglobal(staticPopup.."EditBox"):SetText(name);
					return;
				end
				if ( ChatFrameEditBox:IsVisible() ) then
					ChatFrameEditBox:Insert(name);
				elseif ( HelpFrameOpenTicketText:IsVisible() ) then
					HelpFrameOpenTicketText:Insert(name);
				else
					SendWho("n-"..name);					
				end
				
			else
				ChatFrameEditBox:Hide()
				FriendsFrame_ShowDropdown(name, 1, lineid);
			end
		end
		return;
	end
end
